# Train route

Package provides classes for storing scheduled train routes and calculating current position of train.

See [https://train-map.vercel.app/](https://train-map.vercel.app/)

## Installation
`pip install train_route`